-
Cos’è Mariabackup?
-
Eseguire il backup e il ripristino di MariaDB con Mariabackup
-
Eseguire il backup e il ripristino di MariaDB con mysqldump
-
Eseguire il backup e il ripristino di MariaDB con una soluzione di backup per database
-
Riepilogo

MariaDB è un popolare sistema di gestione di database relazionali (RDBMS) open source progettato per essere una sostituzione diretta di MySQL. È stato creato dagli sviluppatori originali di MySQL dopo che erano sorte preoccupazioni riguardo all’acquisizione di quest’ultimo da parte della Oracle Corporation.
MariaDB presenta un’elevata compatibilità con MySQL e offre la stessa parità binaria delle librerie, corrispondendo esattamente alle API e ai comandi di MySQL. Ciò rende più semplice la migrazione del database da MySQL a MariaDB.
Se stai utilizzando MariaDB, è essenziale conoscere le procedure per eseguire il backup di MariaDB e ripristinarlo. In questo articolo imparerai a eseguire il backup e il ripristino di MariaDB mediante Mariabackup e altri due metodi. Potresti quindi chiederti: cos’è Mariabackup?
Cos’è Mariabackup?
Mariabackup, derivato da Percona XtraBackup, è uno strumento open source creato da MariaDB che consente di eseguire backup online di tabelle InnoDB, MyRocks, Aria e MyISAM in formato fisico.
Opzioni:
| --apply-log | Prepara un backup corrente per il ripristino del server MariaDB. |
| --apply-log-only | Esegui solo la fase di applicazione del log di ripristino. |
| --backup | Esegue il backup di MariaDB. |
| --info-binlog | Specifica il metodo per recuperare le coordinate del log binario dal server. |
| --chiudi-file | Determina se chiudere o meno i gestori di file. |
| --compress | Definisce la compressione del file di backup. |
| --compress-chunk-size | Specifica la dimensione del buffer di lavoro per i thread di compressione. |
| --compress-threads | Specifica il numero di thread per la compressione. |
| --copy-back | Ripristina il backup nella directory dei dati. |
| --database | Sceglie i database e le tabelle da backup. |
Nota: visita la pagina delle opzioni di Mariabackup per ulteriori informazioni.
Funzionalità:
Crea una replica da un backup.
Utilizza strumenti di crittografia e compressione.
Ripristina singole tabelle e partizioni.
Supporta il metodo SST con Glaera Cluster.
Supporta il backup e il ripristino completi, parziali e incrementali.
Esegue backup e ripristini delle tabelle utilizzando la crittografia dei dati a riposo, il motore di archiviazione MyRocks e la compressione delle pagine InnoDB.
Minimizza i blocchi durante il backup e fornisce un supporto ottimale per il backup di tutti i motori di archiviazione di MariaDB Enterprise Backup.
Vantaggi:
Open source e gratuito da utilizzare.
Garantisce un elevato livello di coerenza e integrità dei dati.
Facile da configurare e utilizzare, con documentazione chiara e un’interfaccia intuitiva.
Progettato appositamente per MariaDB, è ottimizzato per quel particolare sistema di gestione di database.
Contro:
Supporta esclusivamente le operazioni di backup e ripristino per MariaDB.
Non supporta la crittografia basata su strumenti di backup e l’opzione di compressione.
Richiede alcune conoscenze relative alle interfacce a riga di comando e alle procedure di backup.
Non supporta la compressione e la crittografia dei dati a riposo per la funzionalità di backup completo.
Non è supportato il backup parziale dei dati MyRocks e il backup incrementale ne memorizzerà una copia completa.
Potrebbe non essere adatto per database molto grandi o per operazioni di backup che devono essere eseguite con frequenza, poiché può consumare una quantità significativa di risorse di sistema.
Fare attenzione a non inserire refusi né a utilizzare opzioni provenienti da versioni più recenti di Mariabackup, poiché il software ignora le opzioni della riga di comando sconosciute senza visualizzare alcun messaggio di errore.
Installa Mariabackup
Su Linux:
Installa tramite un gestore di pacchetti ed esegui come amministratore:
curl -LsS https://r.mariadb.com/downloads/mariadb_repo_setup | sudo bash
Installa con yum/dnf per RHEL, CentOS, Fedora e altre distribuzioni Linux simili:
sudo yum install MariaDB-backup
Installa con apt-get per Debian, Ubuntu e altre distribuzioni Linux simili:
sudo apt-get install mariadb-backup
Installazione con zip per SLES, OpenSUSE e altre distribuzioni Linux simili:
sudo zypper install MariaDB-backup
Su Windows:
1. Installa il pacchetto MSI di MariaDB.
2. Fare clic su mariadb-<major>.<minor>.<patch>.msi.
3. Fare clic su Avanti nella pagina di benvenuto e accettare il contratto di licenza, quindi fare clic su Avanti.
4. Nella pagina Installazione personalizzata, fare clic su Utilità di backup per installarle.
5. Segui la procedura guidata.
Eseguire il backup e il ripristino di MariaDB con Mariabackup
Eseguire il backup dell’intero server di database:
$ mariabackup --backup --target-dir=/var/mariadb/backup/ --user=mariabackup --password=mypassword
Eseguire un backup incrementale (creare prima un backup completo):
$ mariabackup --backup --target-dir=/var/mariadb/inc1/ --incremental-basedir=/var/mariadb/backup/ --user=mariabackup --password=mypassword
Prepara backup coerenti per il ripristino:
$ mariabackup --prepare --target-dir=/var/mariadb/backup/
Ripristina l'intero database:
a. Arrestare il processo del server e assicurarsi che la cartella datadir sia vuota.
b. Eseguire –copy-back per mantenere i file di backup originali o –move-back per spostare i dati nella cartella datadir, con conseguente perdita dei file originali.
$ mariabackup --copy-back --target-dir=/var/mariadb/backup/
c. Avviare il processo del server MariaDB.
Ripristinare le modifiche nel primo backup incrementale e ripetere il passaggio per ciascuno dei backup rimanenti con MariaDB 10.2:
a. Preparare il backup completo di base.
$ mariabackup --prepare --target-dir=/var/mariadb/backup --incremental-dir=/var/mariadb/inc1
b. Sincronizza la base con le modifiche.
$ mariabackup --prepare --target-dir=/var/mariadb/backup --incremental-dir=/var/mariadb/inc1
c. Arrestare il processo del server e assicurarsi che la cartella datadir sia vuota.
d. Eseguire –copy-back per mantenere i file di backup originali oppure –move-back per spostare i dati nella cartella datadir, con conseguente perdita dei file originali.
$ mariabackup --copy-back --target-dir=/var/mariadb/backup/
Ripristina il backup incrementale con MariaDB fino alla versione 10.1:
a. Preparare il backup completo di base.
$ mariabackup --prepare --apply-log-only --target-dir=/var/mariadb/backup
b. Applicare gli incrementi alla base:
$ mariabackup --prepare --apply-log-only --target-dir=/var/mariadb/backup --incremental-dir=/var/mariadb/inc1
c. Arrestare il processo del server e assicurarsi che la cartella datadir sia vuota.
d. Eseguire –copy-back per conservare i file di backup originali oppure –move-back per spostare i dati nella cartella datadir, con conseguente perdita dei file originali.
$ mariabackup --copy-back --target-dir=/var/mariadb/backup/
Eseguire il backup e il ripristino di MariaDB con mysqldump
Mysqldump è uno strumento integrato di MariaDB per il backup, che consente di creare un dump di uno o più database ai fini del backup o del trasferimento in formato CSV, altri formati testuali delimitati o XML; può inoltre essere utilizzato per eseguire il backup e il ripristino di MySQL.
Esporta tutti i database MariaDB:
mysqldump -u xx -p -x -A > /data/backup/dbs.sql
Esporta diversi database e tutti i database:
shell> mysqldump --databases db_name1 [db_name2 ...] > my_databases.sql shell> mysqldump --all-databases > all_databases.sql
Esegui il backup dell'intero database:
shell> mysqldump db_name > backup-file.sql
Backup di un singolo database:
mysqldump --user=xx --password --lock-tables --databases db1 > /data/backup/db1.sql
Esegui il backup di una tabella:
mysqldump --user=xx --password --lock-tables db1 table1 > /data/backup/db1_table1.sql
Ripristina un backup:
mysql -u root -p < backup-file.sql
Eseguire il backup e il ripristino di MariaDB con una soluzione di backup per database
In entrambi i casi, le procedure per eseguire il backup e il ripristino di MariaDB sono tutt’altro che intuitive e user-friendly per un principiante. Prova Vinchin Backup & Recovery, compatibile con 12 piattaforme di virtualizzazione, tra cui VMware, Hyper-V, Xen, RHEV/oVirt, ecc., 2 server fisici, NAS e 6 database, inclusi Oracle DB, MySQL, SQL Server, PostgreSQL, Postgres Pro e MariaDB.

Puoi automatizzare il backup del database con pianificazioni personalizzate e scegliere, con un solo clic, tra backup completi, differenziali, incrementali e dei log (variano in base al tipo di database).
È possibile abilitare la deduplicazione e la compressione dei dati per ridurre le dimensioni complessive del backup e attivare la crittografia dei dati con lo standard AES-256 per garantire la sicurezza.
Ripristina MariaDB nel database originale o in una nuova destinazione di database e prepara una copia di backup esterna in una posizione remota.
Scarica ora la versione di prova gratuita di 60 giorni della nuova versione v7.0:
Processo semplificato di backup di MariaDB:
1. Vai su Backup fisico > Backup del database > Backup e seleziona l’agente di backup del database installato e la fonte del backup.
2. Selezionare il nodo di backup e l’archiviazione sul nodo per il processo.
3. Specificare le strategie di backup, se necessario.

4. Conferma e invia.
Procedura di ripristino facile di MariaDB:
1. Vai su Backup fisico > Backup del database > Ripristina e seleziona la risorsa da ripristinare dai backup del database.
2. Selezionare l’istanza di destinazione.
3. Ripristina nell’origine o in una nuova destinazione e specifica le strategie di ripristino.

4. Conferma e invia.
Riepilogo
Puoi eseguire il backup e il ripristino di MariaDB utilizzando Mariabackup e Mysqldump, ma queste soluzioni non offrono un'interfaccia grafica intuitiva né la varietà di opzioni di backup disponibili in Vinchin Backup & Recovery, una soluzione professionale per il backup dei database. Questo software automatizza il backup e il ripristino dei dati e integra tecnologie avanzate di protezione antimalware, garantendo una protezione completa e affidabile dei dati di MariaDB.
Condividi su: